#!/bin/sh
# Useage: ./loadko.sh [ -r|-i|-a ]
#         -r : rmmod all modules
#         -i : insmod all modules
#    default : rmmod all moules and then insmod them
#

####################Variables Definition##########################

mem_total=512;		# 512M, total mem
mem_start=0x80000000;	# phy mem start

os_mem_size=128;	# 64M, os mem
mmz_start=0x88000000;	# mmz start addr
mmz_size=384M;		# 128M, mmz size

##################################################################

report_error()
{
	echo "******* Error: There's something wrong, please check! *****"
	exit 1
}


calc_mmz_info()
{
        mmz_start=`echo "$mem_start $os_mem_size" |
        awk 'BEGIN { temp = 0; }
        {
                temp = $1/1024/1024 + $2;
        }
        END { printf("0x%x00000\n", temp); }'`

        mmz_size=`echo "$mem_total $os_mem_size" |
        awk 'BEGIN { temp = 0; }
        {
                temp = $1 - $2;
        }
        END { printf("%dM\n", temp); }'`
        echo "mmz_start: $mmz_start, mmz_size: $mmz_size"
}




insert_ko()
{

	# driver load
	insmod /ko/mmz.ko mmz=anonymous,0,$mmz_start,$mmz_size anony=1 || report_error
	
	himm 0x1b300004 0x3f00 #mask GP7-5  HD_RSTB R0 vi_rst pa5 reverse_en
	himm 0x1b300008 0x3d00 
	himm 0x1b300000 0xc00 # R0 vi_rst high
	
	himm 0x28200020 0 #7-5 mux
	
	himm 0x1b000004 0x3f #mask key6 - key1
	himm 0x1b000008 0x0 #input
	
	insmod /ko/fy_media.ko
	insmod /ko/fybase.ko logbuflen=1048576
	insmod /ko/sys.ko

	insmod /ko/viu.ko admode=0 buff_size=$((1920*1080*2)) userpic_mode=0

#	insmod /ko/media_process.ko
	insmod media_process.ko
	insmod /ko/vpu.ko
	insmod /ko/vou.ko

	insmod /ko/fyfb.ko video=vram0_size:21600,vram1_size:0,vram2_size:0,vram3_size:0 fbc=0
	insmod /ko/sccoef_calc.ko

	insmod /ko/vppu.ko wkbuf=4096 vgsbuf=4096
	insmod /ko/jpeg.ko
	insmod /ko/vdu.ko VBSource=1
#	insmod /ko/bgm_cv.ko
	insmod bgm_cv.ko
#	insmod /ko/bgm.ko
	insmod bgm.ko
#	insmod /ko/fh_rc.ko
	insmod fh_rc.ko
#	insmod /ko/veu.ko
	insmod hhe.ko
#	insmod i2s.ko
#
#	insmod extdrv/nvp-6124b.ko
	insmod extdrv/nvp-6158c.ko
	insmod extdrv/dow.ko

	insmod /ko/acw.ko project=none
	

}

remove_ko()
{
	rmmod acw
#	rmmod tp2830.ko
#	rmmod i2s
	rmmod veu
	rmmod fh_rc
	rmmod bgm
	rmmod bgm_cv
	rmmod vdu
	rmmod jpeg
	rmmod vppu
	rmmod sccoef_calc
	rmmod fyfb
	rmmod vou
	rmmod vpu
	rmmod media_process
	rmmod viu
	rmmod sys
	rmmod fybase
	rmmod fy_media
	rmmod mmz

}

load_usage()
{
	echo "Usage:  ./loadko.sh [-option]"
	echo "options:"
	echo "    -i                       insert modules"
	echo "    -r                       remove modules"
	echo "    -a                       remove modules first, then insert modules"
	echo "    -h                       help information"
	echo -e "for example: ./loadko.sh -i\n"
}



######################parse arg###################################
b_arg_insmod=0
b_arg_remove=0


for arg in $@
do
	case $arg in
		"-i")
			b_arg_insmod=1;
			;;

		"-r")
			b_arg_remove=1;
			;;
		"-a")
			b_arg_insmod=1;
			b_arg_remove=1;
			;;

		"-h")
			load_usage;
			;;
	esac
done
#######################parse arg end########################
if [ $os_mem_size -ge $mem_total ] ; then
        echo "[err] os_mem[$os_mem_size], over total_mem[$mem_total]"
        exit;
fi

calc_mmz_info;


#######################Action###############################
if [ $b_arg_remove -eq 1 ]; then
	remove_ko;
fi
if [ $b_arg_insmod -eq 1 ]; then
	insert_ko;
fi

